---
icon: lucide/list-video
---

# Frameprops Tool API

API for extending the Frameprops Tool, which allows you to customize how frame properties are displayed and categorized.

---

[:lucide-box:{ .middle } **Core Classes**](#core-classes)

[:lucide-webhook:{ .middle } **Hook**](#hook)

---

## Core Classes

::: vsview.app.tools.frameprops.api
    options:
        heading_level: 3
        members:
           - CategoryMatcher
           - FormatterProperty


## Hook

::: vsview.app.tools.frameprops.api
    options:
        heading_level: 3
        members:
           - hookimpl
